summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAnson Huang <b20788@freescale.com>2014-06-18 11:09:47 +0800
committerNitin Garg <nitin.garg@freescale.com>2015-04-14 13:59:25 -0500
commit5dee7c2747e67e0edaf4b911fb7154c88b7b611a (patch)
tree96daff082b951642dc1faea91c75f1ee3d355f19
parent98158cac5813043e2974d4545ffb316de7ffa9f5 (diff)
ENGR00318913-1 thermal: imx: update trip temp using default setting
Previously, the critical and passive trip temp settings are from calibration data of hot point, but the lastest chips are only calibrated at 25C and use an universal formula to get real temp, so there is no longer a hot point value in calibration data, need to set the critical and passive trip temp manually instead of getting them from calibration data. Currently the default setting for passive trip temp is 85 C, and critical trip temp is 20 C higher than passive trip temp, which is 105 C. Signed-off-by: Anson Huang <b20788@freescale.com>
-rw-r--r--drivers/thermal/imx_thermal.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/drivers/thermal/imx_thermal.c b/drivers/thermal/imx_thermal.c
index a99c63152b8d..fb66f578a6ed 100644
--- a/drivers/thermal/imx_thermal.c
+++ b/drivers/thermal/imx_thermal.c
@@ -1,5 +1,5 @@
/*
- * Copyright 2013 Freescale Semiconductor, Inc.
+ * Copyright 2013-2014 Freescale Semiconductor, Inc.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License version 2 as
@@ -366,16 +366,16 @@ static int imx_get_sensor_data(struct platform_device *pdev)
data->c2 = n1 * data->c1 + 1000 * t1;
/*
* Set the default passive cooling trip point to 20 °C below the
* maximum die temperature. Can be changed from userspace.
*/
- data->temp_passive = 1000 * (t2 - 20);
+ data->temp_passive = IMX_TEMP_PASSIVE;
/*
- * The maximum die temperature is t2, let's give 5 °C cushion
- * for noise and possible temperature rise between measurements.
+ * Set the default critical trip point to 20 C higher
+ * than passive trip point. Can be changed from userspace.
*/
- data->temp_critical = 1000 * (t2 - 5);
+ data->temp_critical = IMX_TEMP_PASSIVE + 20 * 1000;
return 0;
}
@@ -366,16 +366,16 @@ static int imx_get_sensor_data(struct platform_device *pdev)
data->c2 = n1 * data->c1 + 1000 * t1;
/*
- * Set the default passive cooling trip point to 20 °C below the
- * maximum die temperature. Can be changed from userspace.
+ * Set the default passive cooling trip point to IMX_TEMP_PASSIVE.
+ * Can be changed from userspace.
*/